@@ -143,6 +143,10 @@ def main():
     cmd.add_argument('folder',
                      nargs='?', default='me/skydrive',
                      help='Folder to list contents of (default: %(default)s).')
+    cmd.add_argument('-r', '--range', metavar='{[offset]-[limit] | limit}',
+                    help='List only specified range of objects inside.'
+                         ' Can be either dash-separated "offset-limit" tuple'
+                         ' (any of these can be omitted) or a single "limit" number.')
     cmd.add_argument('-o', '--objects', action='store_true',
                      help='Dump full objects, not just name and id.')
 
@@ -264,7 +268,19 @@ def main():
         res = api('me/skydrive/recent_docs')['data']
 
     elif optz.call == 'ls':
-        res = list(api.listdir(resolve_path(optz.folder)))
+        offset = limit = None
+        if optz.range:
+            span = re.search(r'^(\d+)?[-:](\d+)?$', optz.range)
+            try:
+                if not span:
+                    limit = int(optz.range)
+                else:
+                    offset, limit = map(int, span.groups())
+            except ValueError:
+                parser.error('--range argument must be in the "[offset]-[limit]"'
+                             ' or just "limit" format, with integers as both offset and'
+                             ' limit (if not omitted). Provided: {}'.format(optz.range))
+        res = list(api.listdir(resolve_path(optz.folder), offset=offset, limit=limit))
         if not optz.objects: res = map(op.itemgetter('name'), res)
 
     elif optz.call == 'info':
